@@ -3,6 +3,15 @@
 #[cfg(feature = "asynch")]
 pub mod asynch;
 
+#[cfg(feature = "serde")]
+use serde::{
+    de::{Deserialize, Deserializer},
+    ser::{Serialize, SerializeMap, Serializer},
+};
+
+#[cfg(feature = "serde")]
+use crate::utils::MapCollector;
+
 use crate::internals::lincowcell::{LinCowCell, LinCowCellReadTxn, LinCowCellWriteTxn};
 
 include!("impl.rs");
@@ -25,8 +34,8 @@ impl<K: Clone + Ord + Debug + Sync + Send + 'static, V: Clone + Sync + Send + 's
     }
 }
 
-impl<'a, K: Clone + Ord + Debug + Sync + Send + 'static, V: Clone + Sync + Send + 'static>
-    BptreeMapWriteTxn<'a, K, V>
+impl<K: Clone + Ord + Debug + Sync + Send + 'static, V: Clone + Sync + Send + 'static>
+    BptreeMapWriteTxn<'_, K, V>
 {
     /// Commit the changes from this write transaction. Readers after this point
     /// will be able to percieve these changes.
@@ -37,13 +46,48 @@ impl<'a, K: Clone + Ord + Debug + Sync + Send + 'static, V: Clone + Sync + Send
     }
 }
 
+#[cfg(feature = "serde")]
+impl<K, V> Serialize for BptreeMap<K, V>
+where
+    K: Serialize + Clone + Ord + Debug + Sync + Send + 'static,
+    V: Serialize + Clone + Sync + Send + 'static,
+{
+    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        let txn = self.read();
+
+        let mut state = serializer.serialize_map(Some(txn.len()))?;
+
+        for (key, val) in txn.iter() {
+            state.serialize_entry(key, val)?;
+        }
+
+        state.end()
+    }
+}
+
+#[cfg(feature = "serde")]
+impl<'de, K, V> Deserialize<'de> for BptreeMap<K, V>
+where
+    K: Deserialize<'de> + Clone + Ord + Debug + Sync + Send + 'static,
+    V: Deserialize<'de> + Clone + Sync + Send + 'static,
+{
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        deserializer.deserialize_map(MapCollector::new())
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::BptreeMap;
     use crate::internals::bptree::node::{assert_released, L_CAPACITY};
     // use rand::prelude::*;
     use rand::seq::SliceRandom;
-    use std::iter::FromIterator;
 
     #[test]
     fn test_bptree2_map_basic_write() {
@@ -200,7 +244,7 @@ mod tests {
 
         let r3 = map.read();
         // println!("{:?}", r3.len());
-        assert!(r3.len() == 0);
+        assert!(r3.is_empty());
 
         std::mem::drop(r);
         std::mem::drop(r2);
@@ -264,9 +308,9 @@ mod tests {
         let rd = map.read();
 
         wr.insert(1, 1);
-        assert!(rd.get(&1) == None);
+        assert!(rd.get(&1).is_none());
         wr.commit();
-        assert!(rd.get(&1) == None);
+        assert!(rd.get(&1).is_none());
     }
 
     #[test]
@@ -603,4 +647,18 @@ mod tests {
         // Done!
     }
     */
+
+    #[cfg(feature = "serde")]
+    #[test]
+    fn test_bptreee2_serialize_deserialize() {
+        let map: BptreeMap<usize, usize> = vec![(10, 11), (15, 16), (20, 21)].into_iter().collect();
+
+        let value = serde_json::to_value(&map).unwrap();
+        assert_eq!(value, serde_json::json!({ "10": 11, "15": 16, "20": 21 }));
+
+        let map: BptreeMap<usize, usize> = serde_json::from_value(value).unwrap();
+        let mut vec: Vec<(usize, usize)> = map.read().iter().map(|(k, v)| (*k, *v)).collect();
+        vec.sort_unstable();
+        assert_eq!(vec, [(10, 11), (15, 16), (20, 21)]);
+    }
 }
