@@ -11,8 +11,8 @@ use std::fmt::Debug;
 use std::mem;
 
 use super::iter::{Iter, KeyIter, RangeIter, ValueIter};
+use super::mutiter::RangeMutIter;
 use super::states::*;
-use std::iter::Extend;
 use std::ops::RangeBounds;
 
 use std::sync::Mutex;
@@ -172,6 +172,7 @@ unsafe impl<K: Clone + Ord + Debug + Sync + Send + 'static, V: Clone + Sync + Se
 }
 
 pub(crate) trait CursorReadOps<K: Clone + Ord + Debug, V: Clone> {
+    #[allow(unused)]
     fn get_root_ref(&self) -> &Node<K, V>;
 
     fn get_root(&self) -> *mut Node<K, V>;
@@ -187,17 +188,17 @@ pub(crate) trait CursorReadOps<K: Clone + Ord + Debug, V: Clone> {
         rref.tree_density()
     }
 
-    fn search<'a, 'b, Q: ?Sized>(&'a self, k: &'b Q) -> Option<&'a V>
+    fn search<Q>(&self, k: &Q) -> Option<&V>
     where
         K: Borrow<Q>,
-        Q: Ord,
+        Q: Ord + ?Sized,
     {
         let mut node = self.get_root();
         for _i in 0..65536 {
             if unsafe { (*node).is_leaf() } {
                 let lref = leaf_ref!(node, K, V);
                 return lref.get_ref(k).map(|v| unsafe {
-                    // Strip the lifetime and rebind to the 'a self.
+                    // Strip the lifetime and rebind to the lifetime of `self`.
                     // This is safe because we know that these nodes will NOT
                     // be altered during the lifetime of this txn, so the references
                     // will remain stable.
@@ -213,33 +214,60 @@ pub(crate) trait CursorReadOps<K: Clone + Ord + Debug, V: Clone> {
         panic!("Tree depth exceeded max limit (65536). This may indicate memory corruption.");
     }
 
-    #[allow(clippy::needless_lifetimes)]
-    fn contains_key<'a, 'b, Q: ?Sized>(&'a self, k: &'b Q) -> bool
+    fn contains_key<Q>(&self, k: &Q) -> bool
     where
         K: Borrow<Q>,
-        Q: Ord,
+        Q: Ord + ?Sized,
     {
         self.search(k).is_some()
     }
 
-    fn range<'a, R, T>(&'a self, range: R) -> RangeIter<'a, K, V>
+    fn first_key_value(&self) -> Option<(&K, &V)> {
+        let mut node = self.get_root();
+        for _i in 0..65536 {
+            if unsafe { (*node).is_leaf() } {
+                let lref = leaf_ref!(node, K, V);
+                return lref.min_value();
+            } else {
+                let bref = branch_ref!(node, K, V);
+                node = bref.min_node();
+            }
+        }
+        panic!("Tree depth exceeded max limit (65536). This may indicate memory corruption.");
+    }
+
+    fn last_key_value(&self) -> Option<(&K, &V)> {
+        let mut node = self.get_root();
+        for _i in 0..65536 {
+            if unsafe { (*node).is_leaf() } {
+                let lref = leaf_ref!(node, K, V);
+                return lref.max_value();
+            } else {
+                let bref = branch_ref!(node, K, V);
+                node = bref.max_node();
+            }
+        }
+        panic!("Tree depth exceeded max limit (65536). This may indicate memory corruption.");
+    }
+
+    fn range<'n, R, T>(&'n self, range: R) -> RangeIter<'n, '_, K, V>
     where
         K: Borrow<T>,
-        T: Ord,
+        T: Ord + ?Sized,
         R: RangeBounds<T>,
     {
         RangeIter::new(self.get_root(), range, self.len())
     }
 
-    fn kv_iter(&self) -> Iter<K, V> {
+    fn kv_iter<'n>(&'n self) -> Iter<'n, '_, K, V> {
         Iter::new(self.get_root(), self.len())
     }
 
-    fn k_iter(&self) -> KeyIter<K, V> {
+    fn k_iter<'n>(&'n self) -> KeyIter<'n, '_, K, V> {
         KeyIter::new(self.get_root(), self.len())
     }
 
-    fn v_iter(&self) -> ValueIter<K, V> {
+    fn v_iter<'n>(&'n self) -> ValueIter<'n, '_, K, V> {
         ValueIter::new(self.get_root(), self.len())
     }
 
@@ -528,6 +556,15 @@ impl<K: Clone + Ord + Debug, V: Clone> CursorWrite<K, V> {
     pub(crate) fn tree_density(&self) -> (usize, usize) {
         self.get_root_ref().tree_density()
     }
+
+    pub(crate) fn range_mut<'n, R, T>(&'n mut self, range: R) -> RangeMutIter<'n, '_, K, V>
+    where
+        K: Borrow<T>,
+        T: Ord + ?Sized,
+        R: RangeBounds<T>,
+    {
+        RangeMutIter::new(self, range)
+    }
 }
 
 impl<K: Clone + Ord + Debug, V: Clone> Extend<(K, V)> for CursorWrite<K, V> {
@@ -703,10 +740,8 @@ fn clone_and_insert<K: Clone + Ord + Debug, V: Clone>(
         // move k:v into both closures!
         match branch_ref!(node, K, V).req_clone(txid) {
             Some(cnode) => {
-                //
-                first_seen.push(cnode as *mut Node<K, V>);
-                // println!("ls push 6");
-                last_seen.push(node as *mut Node<K, V>);
+                first_seen.push(cnode);
+                last_seen.push(node);
                 // Not same txn, clone instead.
                 let nmref = branch_ref!(cnode, K, V);
                 let anode_idx = nmref.locate_node(&k);
@@ -1059,12 +1094,10 @@ fn clone_and_remove<K: Clone + Ord + Debug, V: Clone>(
     }
 }
 
-fn path_get_mut_ref<'a, K: Clone + Ord + Debug, V: Clone>(
-    node: *mut Node<K, V>,
-    k: &K,
-) -> Option<&'a mut V>
+fn path_get_mut_ref<'a, K, V>(node: *mut Node<K, V>, k: &K) -> Option<&'a mut V>
 where
-    K: 'a,
+    K: Clone + Ord + Debug + 'a,
+    V: Clone,
 {
     if self_meta!(node).is_leaf() {
         leaf_ref!(node, K, V).get_mut_ref(k)
@@ -1084,7 +1117,7 @@ where
 }
 
 /*
-fn clone_and_split_off_trim_lt<'a, K: Clone + Ord + Debug, V: Clone>(
+fn clone_and_split_off_trim_lt<K: Clone + Ord + Debug, V: Clone>(
     node: *mut Node<K, V>,
     txid: u64,
     k: &K,
@@ -1127,8 +1160,8 @@ fn clone_and_split_off_trim_lt<'a, K: Clone + Ord + Debug, V: Clone>(
 */
 
 /*
-fn clone_and_split_off_prune_lt<'a, K: Clone + Ord + Debug, V: Clone>(
-    node: &'a mut ABNode<K, V>,
+fn clone_and_split_off_prune_lt<K: Clone + Ord + Debug, V: Clone>(
+    node: &mut ABNode<K, V>,
     txid: usize,
     k: &K,
 ) -> CRPruneState<K, V> {
@@ -1768,7 +1801,7 @@ mod tests {
 
         for v in 0..L_CAPACITY {
             let x = wcurs.remove(&v);
-            assert!(x == None);
+            assert!(x.is_none());
         }
 
         mem::drop(wcurs);
@@ -2654,10 +2687,10 @@ mod tests {
                 assert!(wcurs.contains_key(&(v - 1)));
             }
 
-            wcurs.split_off_lt(&v);
+            wcurs.split_off_lt(v);
             assert!(!wcurs.contains_key(&(v - 1)));
             if v < &1024 {
-                assert!(wcurs.contains_key(&v));
+                assert!(wcurs.contains_key(v));
             }
             assert!(wcurs.verify());
             let contents: Vec<_> = wcurs.k_iter().collect();
@@ -2666,6 +2699,25 @@ mod tests {
         }
     }
 
+    #[test]
+    fn test_bptree_cursor_double_extend() {
+        let node: *mut Leaf<isize, isize> = Node::new_leaf(0) as *mut _;
+        let sb = SuperBlock::new_test(1, node as *mut Node<isize, isize>);
+        let mut wcurs = sb.create_writer();
+
+        wcurs.extend([(0, 0), (1, 1), (2, 2), (3, 3)]);
+        assert!(wcurs.len() == 4);
+        assert!(wcurs.verify());
+
+        wcurs.extend([(2, 2), (3, 3), (4, 4), (5, 5)]);
+        assert!(wcurs.len() == 6);
+        assert!(wcurs.verify());
+
+        mem::drop(wcurs);
+        mem::drop(sb);
+        assert_released();
+    }
+
     /*
     #[test]
     fn test_bptree_cursor_get_mut_ref_1() {
