@@ -18,14 +18,14 @@ where
     phantom_v: PhantomData<&'a V>,
 }
 
-impl<'a, K, V> LeafIter<'a, K, V>
+impl<K, V> LeafIter<'_, K, V>
 where
     K: Clone + Ord + Debug,
     V: Clone,
 {
     pub(crate) fn new<T>(root: *mut Node<K, V>, bound: Bound<&T>) -> Self
     where
-        T: Ord,
+        T: Ord + ?Sized,
         K: Borrow<T>,
     {
         // We need to position the VecDeque here.
@@ -158,14 +158,14 @@ where
     phantom_v: PhantomData<&'a V>,
 }
 
-impl<'a, K, V> RevLeafIter<'a, K, V>
+impl<K, V> RevLeafIter<'_, K, V>
 where
     K: Clone + Ord + Debug,
     V: Clone,
 {
     pub(crate) fn new<T>(root: *mut Node<K, V>, bound: Bound<&T>) -> Self
     where
-        T: Ord,
+        T: Ord + ?Sized,
         K: Borrow<T>,
     {
         // We need to position the VecDeque here.
@@ -308,15 +308,15 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for RevLeafIter<'a, K, V> {
 // Wrappers
 
 /// Iterator over references to Key Value pairs stored in the map.
-pub struct Iter<'a, K, V>
+pub struct Iter<'n, 'a, K, V>
 where
     K: Ord + Clone + Debug,
     V: Clone,
 {
-    iter: RangeIter<'a, K, V>,
+    iter: RangeIter<'n, 'a, K, V>,
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> Iter<'a, K, V> {
+impl<K: Clone + Ord + Debug, V: Clone> Iter<'_, '_, K, V> {
     pub(crate) fn new(root: *mut Node<K, V>, length: usize) -> Self {
         let bounds: (Bound<K>, Bound<K>) = (Bound::Unbounded, Bound::Unbounded);
         let iter = RangeIter::new(root, bounds, length);
@@ -324,7 +324,7 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> Iter<'a, K, V> {
     }
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for Iter<'a, K, V> {
+impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for Iter<'_, 'a, K, V> {
     type Item = (&'a K, &'a V);
 
     /// Yield the next key value reference, or `None` if exhausted.
@@ -342,7 +342,7 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for Iter<'a, K, V> {
     }
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for Iter<'a, K, V> {
+impl<K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for Iter<'_, '_, K, V> {
     /// Yield the next key value reference, or `None` if exhausted.
     fn next_back(&mut self) -> Option<Self::Item> {
         self.iter.next_back()
@@ -350,15 +350,15 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for Iter<'a, K, V
 }
 
 /// Iterater over references to Keys stored in the map.
-pub struct KeyIter<'a, K, V>
+pub struct KeyIter<'n, 'a, K, V>
 where
     K: Ord + Clone + Debug,
     V: Clone,
 {
-    iter: Iter<'a, K, V>,
+    iter: Iter<'n, 'a, K, V>,
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> KeyIter<'a, K, V> {
+impl<K: Clone + Ord + Debug, V: Clone> KeyIter<'_, '_, K, V> {
     pub(crate) fn new(root: *mut Node<K, V>, length: usize) -> Self {
         KeyIter {
             iter: Iter::new(root, length),
@@ -366,7 +366,7 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> KeyIter<'a, K, V> {
     }
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for KeyIter<'a, K, V> {
+impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for KeyIter<'_, 'a, K, V> {
     type Item = &'a K;
 
     /// Yield the next key value reference, or `None` if exhausted.
@@ -379,7 +379,7 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for KeyIter<'a, K, V> {
     }
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for KeyIter<'a, K, V> {
+impl<K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for KeyIter<'_, '_, K, V> {
     /// Yield the next key value reference, or `None` if exhausted.
     fn next_back(&mut self) -> Option<Self::Item> {
         self.iter.next_back().map(|(k, _)| k)
@@ -387,15 +387,15 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for KeyIter<'a, K
 }
 
 /// Iterater over references to Values stored in the map.
-pub struct ValueIter<'a, K, V>
+pub struct ValueIter<'n, 'a, K, V>
 where
     K: Ord + Clone + Debug,
     V: Clone,
 {
-    iter: Iter<'a, K, V>,
+    iter: Iter<'n, 'a, K, V>,
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> ValueIter<'a, K, V> {
+impl<K: Clone + Ord + Debug, V: Clone> ValueIter<'_, '_, K, V> {
     pub(crate) fn new(root: *mut Node<K, V>, length: usize) -> Self {
         ValueIter {
             iter: Iter::new(root, length),
@@ -403,7 +403,7 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> ValueIter<'a, K, V> {
     }
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for ValueIter<'a, K, V> {
+impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for ValueIter<'_, 'a, K, V> {
     type Item = &'a V;
 
     /// Yield the next key value reference, or `None` if exhausted.
@@ -416,7 +416,7 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for ValueIter<'a, K, V> {
     }
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for ValueIter<'a, K, V> {
+impl<K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for ValueIter<'_, '_, K, V> {
     /// Yield the next key value reference, or `None` if exhausted.
     fn next_back(&mut self) -> Option<Self::Item> {
         self.iter.next_back().map(|(_, v)| v)
@@ -424,7 +424,7 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for ValueIter<'a,
 }
 
 /// Iterator over references to Key Value pairs stored, bounded by a range.
-pub struct RangeIter<'a, K, V>
+pub struct RangeIter<'n, 'a, K, V>
 where
     K: Ord + Clone + Debug,
     V: Clone,
@@ -434,16 +434,17 @@ where
     right_iter: RevLeafIter<'a, K, V>,
     phantom_k: PhantomData<&'a K>,
     phantom_v: PhantomData<&'a V>,
+    phantom_root: PhantomData<&'n ()>,
 }
 
-impl<'a, K, V> RangeIter<'a, K, V>
+impl<K, V> RangeIter<'_, '_, K, V>
 where
     K: Clone + Ord + Debug,
     V: Clone,
 {
     pub(crate) fn new<R, T>(root: *mut Node<K, V>, range: R, length: usize) -> Self
     where
-        T: Ord,
+        T: Ord + ?Sized,
         K: Borrow<T>,
         R: RangeBounds<T>,
     {
@@ -566,6 +567,7 @@ where
             right_iter,
             phantom_k: PhantomData,
             phantom_v: PhantomData,
+            phantom_root: PhantomData,
         }
     }
 
@@ -577,11 +579,12 @@ where
             right_iter: RevLeafIter::new_base(),
             phantom_k: PhantomData,
             phantom_v: PhantomData,
+            phantom_root: PhantomData,
         }
     }
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for RangeIter<'a, K, V> {
+impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for RangeIter<'_, 'a, K, V> {
     type Item = (&'a K, &'a V);
 
     /// Yield the next key value reference, or `None` if exhausted.
@@ -628,7 +631,7 @@ impl<'a, K: Clone + Ord + Debug, V: Clone> Iterator for RangeIter<'a, K, V> {
     }
 }
 
-impl<'a, K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for RangeIter<'a, K, V> {
+impl<K: Clone + Ord + Debug, V: Clone> DoubleEndedIterator for RangeIter<'_, '_, K, V> {
     /// Yield the next key value reference, or `None` if exhausted.
     fn next_back(&mut self) -> Option<Self::Item> {
         loop {
@@ -1514,7 +1517,7 @@ mod tests {
             Node::new_branch(0, b1node as *mut _, b2node as *mut _);
 
         let bounds: (Bound<usize>, Bound<usize>) = (Unbounded, Unbounded);
-        let test_iter: RangeIter<'_, usize, usize> =
+        let test_iter: RangeIter<usize, usize> =
             RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
         assert!(test_iter.count() == (L_CAPACITY * 4));
 
@@ -1522,7 +1525,7 @@ mod tests {
             for i in 0..L_CAPACITY {
                 let l_bound = (j * 10) + i;
                 let bounds: (Bound<usize>, Bound<usize>) = (Included(l_bound), Unbounded);
-                let test_iter: RangeIter<'_, usize, usize> =
+                let test_iter: RangeIter<usize, usize> =
                     RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
                 let i_count = test_iter.count();
                 let x_count = ((5 - j) * L_CAPACITY) - i;
@@ -1535,7 +1538,7 @@ mod tests {
             for i in 0..L_CAPACITY {
                 let l_bound = (j * 10) + i;
                 let bounds: (Bound<usize>, Bound<usize>) = (Excluded(l_bound), Unbounded);
-                let test_iter: RangeIter<'_, usize, usize> =
+                let test_iter: RangeIter<usize, usize> =
                     RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
                 let i_count = test_iter.count();
                 let x_count = ((5 - j) * L_CAPACITY) - (i + 1);
@@ -1560,7 +1563,7 @@ mod tests {
             Node::new_branch(0, b1node as *mut _, b2node as *mut _);
 
         let bounds: (Bound<usize>, Bound<usize>) = (Unbounded, Unbounded);
-        let test_iter: RangeIter<'_, usize, usize> =
+        let test_iter: RangeIter<usize, usize> =
             RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
 
         assert!(test_iter.count() == (L_CAPACITY * 4));
@@ -1569,7 +1572,7 @@ mod tests {
             for i in 0..L_CAPACITY {
                 let r_bound = (j * 10) + i;
                 let bounds: (Bound<usize>, Bound<usize>) = (Unbounded, Included(r_bound));
-                let test_iter: RangeIter<'_, usize, usize> =
+                let test_iter: RangeIter<usize, usize> =
                     RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
                 let i_count = test_iter.count();
                 let x_count = ((L_CAPACITY * 4) - (((4 - j) * L_CAPACITY) + (L_CAPACITY - i))) + 1;
@@ -1582,7 +1585,7 @@ mod tests {
             for i in 0..L_CAPACITY {
                 let r_bound = (j * 10) + i;
                 let bounds: (Bound<usize>, Bound<usize>) = (Unbounded, Excluded(r_bound));
-                let test_iter: RangeIter<'_, usize, usize> =
+                let test_iter: RangeIter<usize, usize> =
                     RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
                 let i_count = test_iter.count();
                 let x_count = (L_CAPACITY * 4) - (((4 - j) * L_CAPACITY) + (L_CAPACITY - i));
@@ -1607,7 +1610,7 @@ mod tests {
             Node::new_branch(0, b1node as *mut _, b2node as *mut _);
 
         let bounds: (Bound<usize>, Bound<usize>) = (Unbounded, Unbounded);
-        let test_iter: RangeIter<'_, usize, usize> =
+        let test_iter: RangeIter<usize, usize> =
             RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
         assert!(test_iter.rev().count() == (L_CAPACITY * 4));
 
@@ -1615,7 +1618,7 @@ mod tests {
             for i in 0..L_CAPACITY {
                 let l_bound = (j * 10) + i;
                 let bounds: (Bound<usize>, Bound<usize>) = (Included(l_bound), Unbounded);
-                let test_iter: RangeIter<'_, usize, usize> =
+                let test_iter: RangeIter<usize, usize> =
                     RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
                 let i_count = test_iter.rev().count();
                 let x_count = ((5 - j) * L_CAPACITY) - i;
@@ -1628,7 +1631,7 @@ mod tests {
             for i in 0..L_CAPACITY {
                 let l_bound = (j * 10) + i;
                 let bounds: (Bound<usize>, Bound<usize>) = (Excluded(l_bound), Unbounded);
-                let test_iter: RangeIter<'_, usize, usize> =
+                let test_iter: RangeIter<usize, usize> =
                     RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
                 let i_count = test_iter.rev().count();
                 let x_count = ((5 - j) * L_CAPACITY) - (i + 1);
@@ -1653,7 +1656,7 @@ mod tests {
             Node::new_branch(0, b1node as *mut _, b2node as *mut _);
 
         let bounds: (Bound<usize>, Bound<usize>) = (Unbounded, Unbounded);
-        let test_iter: RangeIter<'_, usize, usize> =
+        let test_iter: RangeIter<usize, usize> =
             RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
 
         assert!(test_iter.rev().count() == (L_CAPACITY * 4));
@@ -1662,7 +1665,7 @@ mod tests {
             for i in 0..L_CAPACITY {
                 let r_bound = (j * 10) + i;
                 let bounds: (Bound<usize>, Bound<usize>) = (Unbounded, Included(r_bound));
-                let test_iter: RangeIter<'_, usize, usize> =
+                let test_iter: RangeIter<usize, usize> =
                     RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
                 let i_count = test_iter.rev().count();
                 let x_count = ((L_CAPACITY * 4) - (((4 - j) * L_CAPACITY) + (L_CAPACITY - i))) + 1;
@@ -1675,7 +1678,7 @@ mod tests {
             for i in 0..L_CAPACITY {
                 let r_bound = (j * 10) + i;
                 let bounds: (Bound<usize>, Bound<usize>) = (Unbounded, Excluded(r_bound));
-                let test_iter: RangeIter<'_, usize, usize> =
+                let test_iter: RangeIter<usize, usize> =
                     RangeIter::new(root as *mut _, bounds, L_CAPACITY * 4);
                 let i_count = test_iter.rev().count();
                 let x_count = (L_CAPACITY * 4) - (((4 - j) * L_CAPACITY) + (L_CAPACITY - i));
