@@ -10,6 +10,7 @@ use sptr::Strict;
 use crate::internals::lincowcell::LinCowCellCapable;
 
 use std::borrow::Borrow;
+use std::cmp::Ordering;
 use std::collections::{BTreeSet, VecDeque};
 use std::fmt::{self, Debug};
 use std::marker::PhantomData;
@@ -77,10 +78,10 @@ macro_rules! hash_key {
 }
 
 #[cfg(all(test, not(miri)))]
-thread_local!(static ALLOC_LIST: Mutex<BTreeSet<Ptr>> = Mutex::new(BTreeSet::new()));
+thread_local!(static ALLOC_LIST: Mutex<BTreeSet<Ptr>> = const { Mutex::new(BTreeSet::new()) });
 
 #[cfg(all(test, not(miri)))]
-thread_local!(static WRITE_LIST: Mutex<BTreeSet<Ptr>> = Mutex::new(BTreeSet::new()));
+thread_local!(static WRITE_LIST: Mutex<BTreeSet<Ptr>> = const { Mutex::new(BTreeSet::new()) });
 
 #[cfg(test)]
 fn assert_released() {
@@ -95,14 +96,38 @@ fn assert_released() {
     }
 }
 
-#[derive(Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
+#[derive(Clone, Copy)]
 pub(crate) struct Ptr {
     // We essential are using this as a void pointer for provenance reasons.
     p: *mut i32,
 }
 
+impl PartialEq for Ptr {
+    fn eq(&self, other: &Self) -> bool {
+        let s = self.p.map_addr(|a| a & UNTAG);
+        let o = other.p.map_addr(|a| a & UNTAG);
+        s == o
+    }
+}
+
+impl Eq for Ptr {}
+
+impl PartialOrd for Ptr {
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
+        Some(self.cmp(other))
+    }
+}
+
+impl Ord for Ptr {
+    fn cmp(&self, other: &Self) -> Ordering {
+        let s = self.p.map_addr(|a| a & UNTAG);
+        let o = other.p.map_addr(|a| a & UNTAG);
+        s.cmp(&o)
+    }
+}
+
 impl Debug for Ptr {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_struct("Ptr")
             .field("p", &self.p)
             .field("bucket", &self.is_bucket())
@@ -483,15 +508,15 @@ pub(crate) trait CursorReadOps<K: Clone + Hash + Eq + Debug, V: Clone> {
 
     fn get_txid(&self) -> u64;
 
-    fn hash_key<'a, 'b, Q: ?Sized>(&'a self, k: &'b Q) -> u64
+    fn hash_key<Q>(&self, k: &Q) -> u64
     where
         K: Borrow<Q>,
-        Q: Hash + Eq;
+        Q: Hash + Eq + ?Sized;
 
-    fn search<'a, 'b, Q: ?Sized>(&'a self, h: u64, k: &'b Q) -> Option<&'a V>
+    fn search<Q>(&self, h: u64, k: &Q) -> Option<&V>
     where
         K: Borrow<Q>,
-        Q: Hash + Eq,
+        Q: Hash + Eq + ?Sized,
     {
         let mut node = self.get_root_ptr();
         for d in 0..MAX_HEIGHT {
@@ -535,6 +560,7 @@ pub(crate) trait CursorReadOps<K: Clone + Hash + Eq + Debug, V: Clone> {
         ValueIter::new(self.get_root_ptr(), self.len())
     }
 
+    #[allow(unused)]
     fn verify_inner(&self, expect_clean: bool) {
         let root = self.get_root_ptr();
         assert!(root.is_branch());
@@ -570,6 +596,7 @@ pub(crate) trait CursorReadOps<K: Clone + Hash + Eq + Debug, V: Clone> {
         assert!(length == self.len());
     }
 
+    #[allow(unused)]
     fn verify(&self);
 }
 
@@ -807,10 +834,24 @@ impl<K: Clone + Hash + Eq + Debug, V: Clone> CursorWrite<K, V> {
                     let datum = &tgt_bkt[0];
                     if datum.h == h && k.eq(datum.k.borrow()) {
                         bref.nodes[idx] = Ptr::null_mut();
-                        // Regardless of the state, we can defer the free
+
+                        // There is a bit of a difficult case here. If a pointer
+                        // is dirty, then it must also have been allocated in
+                        // this txn. It's possible we risk leaking the memory
+                        // here since the node will be in first_seen, and if we
+                        // commit after a insert + remove + insert then the node
+                        // risks orphaning. However, this also leads to a possible
+                        // double free since if we free here AND a rollback occurs
+                        // then we haven't dropped the node.
+                        //
+                        // So this is a sticky situation - As a result we have to
+                        // walk the first_seen and remove this element before we
+                        // do this out-of-band free.
                         let v = if tgt_ptr.is_dirty() {
                             let tgt_bkt_mut = tgt_ptr.as_bucket_mut::<K, V>();
                             let Datum { v, .. } = tgt_bkt_mut.remove(0);
+                            // Keep any pointer that ISNT the one we are oob freeing.
+                            self.first_seen.retain(|e| *e != tgt_ptr);
                             tgt_ptr.free::<K, V>();
                             v
                         } else {
@@ -988,10 +1029,10 @@ impl<K: Clone + Hash + Eq + Debug, V: Clone> CursorReadOps<K, V> for CursorWrite
         self.txid
     }
 
-    fn hash_key<'a, 'b, Q: ?Sized>(&'a self, k: &'b Q) -> u64
+    fn hash_key<Q>(&self, k: &Q) -> u64
     where
         K: Borrow<Q>,
-        Q: Hash + Eq,
+        Q: Hash + Eq + ?Sized,
     {
         hash_key!(self, k)
     }
@@ -1055,10 +1096,10 @@ impl<K: Clone + Hash + Eq + Debug, V: Clone> CursorReadOps<K, V> for CursorRead<
         self.txid
     }
 
-    fn hash_key<'a, 'b, Q: ?Sized>(&'a self, k: &'b Q) -> u64
+    fn hash_key<Q>(&self, k: &Q) -> u64
     where
         K: Borrow<Q>,
-        Q: Hash + Eq,
+        Q: Hash + Eq + ?Sized,
     {
         hash_key!(self, k)
     }
